# SPDX-License-Identifier: Apache-2.0
# Copyright (c) 2023 Intel Corporation

from sysinv.common import exception
from sysinv.helm import base

from k8sapp_intel_ethernet_operator.common import constants as app_constants


class SriovNetworkOperatorHelm(base.FluxCDBaseHelm):
    """Class to encapsulate helm operations for the Sriov Network Operator chart"""

    SUPPORTED_NAMESPACES = base.BaseHelm.SUPPORTED_NAMESPACES + [
        app_constants.HELM_NS_INTEL_ETHERNET_OPERATOR
    ]
    SUPPORTED_APP_NAMESPACES = {
        app_constants.HELM_APP_INTEL_ETHERNET_OPERATOR: base.BaseHelm.SUPPORTED_NAMESPACES
        + [app_constants.HELM_NS_INTEL_ETHERNET_OPERATOR],
    }

    SERVICE_NAME = app_constants.HELM_APP_INTEL_ETHERNET_OPERATOR

    CHART = app_constants.HELM_CHART_SRIOV_NETWORK_OPERATOR
    HELM_RELEASE = app_constants.FLUXCD_HELM_RELEASE_SRIOV_NETWORK_OPERATOR

    def get_namespaces(self):
        return self.SUPPORTED_NAMESPACES

    def get_overrides(self, namespace=None):
        overrides = {app_constants.HELM_NS_INTEL_ETHERNET_OPERATOR: {}}

        if namespace in self.SUPPORTED_NAMESPACES:
            return overrides[namespace]
        elif namespace:
            raise exception.InvalidHelmNamespace(chart=self.CHART, namespace=namespace)
        else:
            return overrides
